summaryrefslogtreecommitdiff
path: root/pyflakes/checker.py
diff options
context:
space:
mode:
Diffstat (limited to 'pyflakes/checker.py')
-rw-r--r--pyflakes/checker.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/pyflakes/checker.py b/pyflakes/checker.py
index 480ee00..b8d7be7 100644
--- a/pyflakes/checker.py
+++ b/pyflakes/checker.py
@@ -632,11 +632,11 @@ class Checker(object):
builtIns.update(_customBuiltIns.split(','))
del _customBuiltIns
# TODO: tokens= is required to perform checks on type comments, eventually
# make this a required positional argument. For now it is defaulted
# to `()` for api compatibility.
def __init__(self, tree, filename='(none)', builtins=None,
- withDoctest='PYFLAKES_DOCTEST' in os.environ, tokens=()):
+ withDoctest='PYFLAKES_DOCTEST' in os.environ, file_tokens=()):
self._nodeHandlers = {}
self._deferredFunctions = []
self._deferredAssignments = []
@@ -652,7 +652,7 @@ class Checker(object):
raise RuntimeError('No scope implemented for the node %r' % tree)
self.exceptHandlers = [()]
self.root = tree
- self._type_comments = _collect_type_comments(tree, tokens)
+ self._type_comments = _collect_type_comments(tree, file_tokens)
for builtin in self.builtIns:
self.addBinding(None, Builtin(builtin))
self.handleChildren(tree)
@@ -632,11 +632,11 @@ class Checker(object):
builtIns.update(_customBuiltIns.split(','))
del _customBuiltIns
- # TODO: tokens= is required to perform checks on type comments, eventually
- # make this a required positional argument. For now it is defaulted
- # to `()` for api compatibility.
+ # TODO: file_tokens= is required to perform checks on type comments,
+ # eventually make this a required positional argument. For now it
+ # is defaulted to `()` for api compatibility.
def __init__(self, tree, filename='(none)', builtins=None,